(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Friday 5 July 02 18:29:50 tews@ithif51>
 *
 * adt theories
 *
 * $Id: adt_theory.mli,v 1.5 2002/07/18 13:43:20 tews Exp $
 *
 *)


open Classtypes

class ccsl_isar_start_adt
  : ccsl_iface_type -> ccsl_sig_theory_type

class ccsl_isar_close_adt
  : ccsl_iface_type -> ccsl_sig_theory_type

class ccsl_pvs_adt_theory 
  : ccsl_iface_type ->  ccsl_adt_theory_type 
  
class ccsl_isa_adt_theory
  : ccsl_iface_type -> ccsl_adt_theory_type

class ccsl_isa_adtutil_theory
  : ccsl_iface_type -> ccsl_adt_theory_type

class ccsl_adt_every_theory
  : ccsl_iface_type -> ccsl_adt_theory_type

class ccsl_adt_rellift_theory 
  : ccsl_iface_type -> ccsl_adt_theory_type

class ccsl_adt_map_theory 
  : ccsl_iface_type -> ccsl_adt_theory_type

(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

